try:
    import importlib.metadata
    __version__ = importlib.metadata.version("biopb")
except:
    pass

from biopb.image.rpc_object_detection_pb2_grpc import ObjectDetection
from biopb.image.rpc_object_detection_pb2_grpc import ObjectDetectionServicer
from biopb.image.rpc_object_detection_pb2_grpc import ObjectDetectionStub
from biopb.image.rpc_object_detection_pb2_grpc import add_ObjectDetectionServicer_to_server

from biopb.image.rpc_process_image_pb2 import ProcessRequest, ProcessResponse, OpNames
from biopb.image.rpc_process_image_pb2_grpc import ProcessImage, ProcessImageServicer, ProcessImageStub
from biopb.image.rpc_process_image_pb2_grpc import add_ProcessImageServicer_to_server

from biopb.image.detection_request_pb2 import DetectionRequest
from biopb.image.detection_response_pb2 import DetectionResponse, ScoredROI
from biopb.image.bindata_pb2 import BinData
from biopb.image.detection_settings_pb2 import DetectionSettings
from biopb.image.image_data_pb2 import ImageData, Pixels, ImageAnnotation
from biopb.image.roi_pb2 import ROI, Rectangle, Mask, Mesh, Polygon, Point



import numpy as np
from . import Pixels, BinData

def serialize_from_numpy(np_img: np.ndarray, **kwargs)->Pixels:
    '''  convert numpy array representation of image to protobuf representation

    Args:
        np_img: image in numpy array. The dimension order is assumed to be [Y, X] for 
            2d array, [Y, X, C] for 3d array and [Z, Y, X, C] for 4D array
        **kwargs: additional metadata, e.g. physical_size_x etc (pixel size)

    Returns:
        protobuf Pixels
    '''
    byteorder = np_img.dtype.byteorder
    if byteorder == "=":
        import sys
        byteorder = "<" if sys.byteorder == 'little' else ">"

    endianness = 1 if byteorder == "<" else 0

    if np_img.ndim == 2:
        np_img = np_img[np.newaxis, :, :, np.newaxis]
    elif np_img.ndim == 3:
        np_img = np_img[np.newaxis, :, :, :]
    elif np_img.ndim != 4:
        raise ValueError(f"Cannot intepret data of dim {np_img.ndim}.")

    return Pixels(
        bindata = BinData(data=np_img.tobytes(), endianness=endianness),
        size_x = np_img.shape[2],
        size_y = np_img.shape[1],
        size_c = np_img.shape[3],
        size_z = np_img.shape[0],
        dimension_order = "CXYZT",
        dtype = np_img.dtype.str,
        **kwargs,
    )


def deserialize_to_numpy(pixels:Pixels) -> np.ndarray:
    '''  convert protobuf ImageData to a numpy array

    Args:
        pixels: protobuf data
    
    Returns:
        4d Numpy array in [Z, Y, X, C] order. Singleton dimensions are kept as is.
        Note the np array has a fixed dimension order, independent of the input 
        stream. The dtype and byteorder of the np array is the same as the input.
    '''
    def _get_dtype(pixels:Pixels) -> np.dtype:
        dt = np.dtype(pixels.dtype)

        if pixels.bindata.endianness == BinData.Endianness.BIG:
            dt = dt.newbyteorder(">")
        else:
            dt = dt.newbyteorder("<")
        
        return dt

    if pixels.size_t > 1:
        raise ValueError("Image data has a non-singleton T dimension.")

    np_img = np.frombuffer(
        pixels.bindata.data, 
        dtype=_get_dtype(pixels),
    )

    # The dimension_order describe axis order but in the F_order convention
    # Numpy default is C_order, so we reverse the sequence. Lacss expect the 
    # final dimension order to be "ZYXC"
    dim_order_c = pixels.dimension_order[::-1].upper()
    dims = dict(
        Z = pixels.size_z or 1,
        Y = pixels.size_y or 1,
        X = pixels.size_x or 1,
        C = pixels.size_c or 1,
        T = 1,
    )
    dim_orig = [dim_order_c.find(k) for k in "ZYXCT"]
    shape_orig = [ dims[k] for k in dim_order_c ]

    np_img = np_img.reshape(shape_orig).transpose(dim_orig)

    np_img = np_img.squeeze(axis=-1) # remove T

    return np_img



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/roi.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/roi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.image import bindata_pb2 as biopb_dot_image_dot_bindata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/image/roi.proto\x12\x0b\x62iopb.image\x1a\x19\x62iopb/image/bindata.proto\"<\n\x05Point\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x11\n\x01z\x18\x03 \x01(\x02H\x00R\x01z\x88\x01\x01\x42\x04\n\x02_z\"q\n\tRectangle\x12-\n\x08top_left\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointR\x07topLeft\x12\x35\n\x0c\x62ottom_right\x18\x02 \x01(\x0b\x32\x12.biopb.image.PointR\x0b\x62ottomRight\"m\n\x04Mask\x12\x34\n\trectangle\x18\x01 \x01(\x0b\x32\x16.biopb.image.RectangleR\trectangle\x12/\n\x08\x62in_data\x18\x02 \x01(\x0b\x32\x14.biopb.image.BinDataR\x07\x62inData\"a\n\x07\x45llipse\x12*\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointR\x06\x63\x65nter\x12*\n\x06radius\x18\x02 \x01(\x0b\x32\x12.biopb.image.PointR\x06radius\"5\n\x07Polygon\x12*\n\x06points\x18\x01 \x03(\x0b\x32\x12.biopb.image.PointR\x06points\"\xdc\x01\n\x04Mesh\x12(\n\x05verts\x18\x01 \x03(\x0b\x32\x12.biopb.image.PointR\x05verts\x12,\n\x05\x66\x61\x63\x65s\x18\x02 \x03(\x0b\x32\x16.biopb.image.Mesh.FaceR\x05\x66\x61\x63\x65s\x1a|\n\x04\x46\x61\x63\x65\x12\x0e\n\x02p1\x18\x01 \x01(\rR\x02p1\x12\x0e\n\x02p2\x18\x02 \x01(\rR\x02p2\x12\x0e\n\x02p3\x18\x03 \x01(\rR\x02p3\x12,\n\x07normals\x18\x04 \x03(\x0b\x32\x12.biopb.image.PointR\x07normals\x12\x16\n\x06values\x18\x05 \x03(\x02R\x06values\"\xa8\x02\n\x03ROI\x12*\n\x05point\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointH\x00R\x05point\x12\x36\n\trectangle\x18\x02 \x01(\x0b\x32\x16.biopb.image.RectangleH\x00R\trectangle\x12\x30\n\x07\x65llipse\x18\x03 \x01(\x0b\x32\x14.biopb.image.EllipseH\x00R\x07\x65llipse\x12\x30\n\x07polygon\x18\x04 \x01(\x0b\x32\x14.biopb.image.PolygonH\x00R\x07polygon\x12\'\n\x04mesh\x18\x05 \x01(\x0b\x32\x11.biopb.image.MeshH\x00R\x04mesh\x12\'\n\x04mask\x18\x06 \x01(\x0b\x32\x11.biopb.image.MaskH\x00R\x04maskB\x07\n\x05shapeB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.roi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_POINT']._serialized_start=65
  _globals['_POINT']._serialized_end=125
  _globals['_RECTANGLE']._serialized_start=127
  _globals['_RECTANGLE']._serialized_end=240
  _globals['_MASK']._serialized_start=242
  _globals['_MASK']._serialized_end=351
  _globals['_ELLIPSE']._serialized_start=353
  _globals['_ELLIPSE']._serialized_end=450
  _globals['_POLYGON']._serialized_start=452
  _globals['_POLYGON']._serialized_end=505
  _globals['_MESH']._serialized_start=508
  _globals['_MESH']._serialized_end=728
  _globals['_MESH_FACE']._serialized_start=604
  _globals['_MESH_FACE']._serialized_end=728
  _globals['_ROI']._serialized_start=731
  _globals['_ROI']._serialized_end=1027
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/metadata.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import project_pb2 as biopb_dot_ome_dot_project__pb2
from biopb.ome import dataset_pb2 as biopb_dot_ome_dot_dataset__pb2
from biopb.ome import folder_pb2 as biopb_dot_ome_dot_folder__pb2
from biopb.ome import experiment_pb2 as biopb_dot_ome_dot_experiment__pb2
from biopb.ome import plate_pb2 as biopb_dot_ome_dot_plate__pb2
from biopb.ome import screen_pb2 as biopb_dot_ome_dot_screen__pb2
from biopb.ome import experimenter_pb2 as biopb_dot_ome_dot_experimenter__pb2
from biopb.ome import experimenter_group_pb2 as biopb_dot_ome_dot_experimenter__group__pb2
from biopb.ome import instrument_pb2 as biopb_dot_ome_dot_instrument__pb2
from biopb.ome import image_pb2 as biopb_dot_ome_dot_image__pb2
from biopb.ome import annotation_pb2 as biopb_dot_ome_dot_annotation__pb2
from biopb.ome import roi_pb2 as biopb_dot_ome_dot_roi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62iopb/ome/metadata.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/project.proto\x1a\x17\x62iopb/ome/dataset.proto\x1a\x16\x62iopb/ome/folder.proto\x1a\x1a\x62iopb/ome/experiment.proto\x1a\x15\x62iopb/ome/plate.proto\x1a\x16\x62iopb/ome/screen.proto\x1a\x1c\x62iopb/ome/experimenter.proto\x1a\"biopb/ome/experimenter_group.proto\x1a\x1a\x62iopb/ome/instrument.proto\x1a\x15\x62iopb/ome/image.proto\x1a\x1a\x62iopb/ome/annotation.proto\x1a\x13\x62iopb/ome/roi.proto\"\x8d\x0e\n\x08Metadata\x12=\n\x08projects\x18\x01 \x03(\x0b\x32!.biopb.ome.Metadata.ProjectsEntryR\x08projects\x12=\n\x08\x64\x61tasets\x18\x02 \x03(\x0b\x32!.biopb.ome.Metadata.DatasetsEntryR\x08\x64\x61tasets\x12:\n\x07\x66olders\x18\x03 \x03(\x0b\x32 .biopb.ome.Metadata.FoldersEntryR\x07\x66olders\x12\x46\n\x0b\x65xperiments\x18\x04 \x03(\x0b\x32$.biopb.ome.Metadata.ExperimentsEntryR\x0b\x65xperiments\x12\x37\n\x06plates\x18\x05 \x03(\x0b\x32\x1f.biopb.ome.Metadata.PlatesEntryR\x06plates\x12:\n\x07screens\x18\x06 \x03(\x0b\x32 .biopb.ome.Metadata.ScreensEntryR\x07screens\x12I\n\x0c\x65xperimenter\x18\x07 \x03(\x0b\x32%.biopb.ome.Metadata.ExperimenterEntryR\x0c\x65xperimenter\x12\\\n\x13\x65xperimenter_groups\x18\x08 \x03(\x0b\x32+.biopb.ome.Metadata.ExperimenterGroupsEntryR\x12\x65xperimenterGroups\x12\x46\n\x0binstruments\x18\t \x03(\x0b\x32$.biopb.ome.Metadata.InstrumentsEntryR\x0binstruments\x12\x37\n\x06images\x18\n \x03(\x0b\x32\x1f.biopb.ome.Metadata.ImagesEntryR\x06images\x12\x31\n\x04rois\x18\x0b \x03(\x0b\x32\x1d.biopb.ome.Metadata.RoisEntryR\x04rois\x12\x46\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32$.biopb.ome.Metadata.AnnotationsEntryR\x0b\x61nnotations\x1aO\n\rProjectsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.ProjectR\x05value:\x02\x38\x01\x1aO\n\rDatasetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.DatasetR\x05value:\x02\x38\x01\x1aM\n\x0c\x46oldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FolderR\x05value:\x02\x38\x01\x1aU\n\x10\x45xperimentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.ExperimentR\x05value:\x02\x38\x01\x1aK\n\x0bPlatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x10.biopb.ome.PlateR\x05value:\x02\x38\x01\x1aM\n\x0cScreensEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.ScreenR\x05value:\x02\x38\x01\x1aX\n\x11\x45xperimenterEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.biopb.ome.ExperimenterR\x05value:\x02\x38\x01\x1a\x63\n\x17\x45xperimenterGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.biopb.ome.ExperimenterGroupR\x05value:\x02\x38\x01\x1aU\n\x10InstrumentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.InstrumentR\x05value:\x02\x38\x01\x1aK\n\x0bImagesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x10.biopb.ome.ImageR\x05value:\x02\x38\x01\x1aG\n\tRoisEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x0e.biopb.ome.ROIR\x05value:\x02\x38\x01\x1aU\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.AnnotationR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_METADATA_PROJECTSENTRY']._loaded_options = None
  _globals['_METADATA_PROJECTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_DATASETSENTRY']._loaded_options = None
  _globals['_METADATA_DATASETSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_FOLDERSENTRY']._loaded_options = None
  _globals['_METADATA_FOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTSENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_PLATESENTRY']._loaded_options = None
  _globals['_METADATA_PLATESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_SCREENSENTRY']._loaded_options = None
  _globals['_METADATA_SCREENSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTERENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_INSTRUMENTSENTRY']._loaded_options = None
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_IMAGESENTRY']._loaded_options = None
  _globals['_METADATA_IMAGESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ROISENTRY']._loaded_options = None
  _globals['_METADATA_ROISENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA']._serialized_start=355
  _globals['_METADATA']._serialized_end=2160
  _globals['_METADATA_PROJECTSENTRY']._serialized_start=1163
  _globals['_METADATA_PROJECTSENTRY']._serialized_end=1242
  _globals['_METADATA_DATASETSENTRY']._serialized_start=1244
  _globals['_METADATA_DATASETSENTRY']._serialized_end=1323
  _globals['_METADATA_FOLDERSENTRY']._serialized_start=1325
  _globals['_METADATA_FOLDERSENTRY']._serialized_end=1402
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_start=1404
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_end=1489
  _globals['_METADATA_PLATESENTRY']._serialized_start=1491
  _globals['_METADATA_PLATESENTRY']._serialized_end=1566
  _globals['_METADATA_SCREENSENTRY']._serialized_start=1568
  _globals['_METADATA_SCREENSENTRY']._serialized_end=1645
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_start=1647
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_end=1735
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_start=1737
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_end=1836
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_start=1838
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_end=1923
  _globals['_METADATA_IMAGESENTRY']._serialized_start=1925
  _globals['_METADATA_IMAGESENTRY']._serialized_end=2000
  _globals['_METADATA_ROISENTRY']._serialized_start=2002
  _globals['_METADATA_ROISENTRY']._serialized_end=2073
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_start=2075
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_end=2160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/annotation.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/annotation.proto\x12\tbiopb.ome\x1a\x19google/protobuf/any.proto\"\x87\x01\n\nAnnotation\x12\x34\n\nannotation\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\nannotation\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12!\n\x0c\x61nnotator_id\x18\x03 \x01(\tR\x0b\x61nnotatorIdB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_ANNOTATION']._serialized_start=69
  _globals['_ANNOTATION']._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/filter_set.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/filter_set.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/filter_set.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x8a\x02\n\tFilterSet\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12\x30\n\x14\x65xcitation_filter_id\x18\x03 \x01(\tR\x12\x65xcitationFilterId\x12,\n\x12\x64ichroic_filter_id\x18\x04 \x01(\tR\x10\x64ichroicFilterId\x12,\n\x12\x65mission_filter_id\x18\x05 \x01(\tR\x10\x65missionFilterId\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.filter_set_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_FILTERSET']._serialized_start=77
  _globals['_FILTERSET']._serialized_end=343
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from biopb.image import detection_request_pb2 as biopb_dot_image_dot_detection__request__pb2
from biopb.image import detection_response_pb2 as biopb_dot_image_dot_detection__response__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


class ObjectDetectionStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RunDetection = channel.unary_unary(
                '/biopb.image.ObjectDetection/RunDetection',
                request_serializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
                response_deserializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
                _registered_method=True)
        self.RunDetectionStream = channel.stream_stream(
                '/biopb.image.ObjectDetection/RunDetectionStream',
                request_serializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
                response_deserializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
                _registered_method=True)
        self.RunDetectionOnGrid = channel.stream_unary(
                '/biopb.image.ObjectDetection/RunDetectionOnGrid',
                request_serializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
                response_deserializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
                _registered_method=True)
        self.RunModelAdaptation = channel.stream_unary(
                '/biopb.image.ObjectDetection/RunModelAdaptation',
                request_serializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_any__pb2.Any.FromString,
                _registered_method=True)


class ObjectDetectionServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RunDetection(self, request, context):
        """Implementing the `RunDetection` call is mandatory. The rest are optional. 

        Unitary call for computing cell detection / segmentation. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDetectionStream(self, request_iterator, context):
        """The streaming version allows dynamic updating of the DetectionRequest and
        getting updated results. For example, a client may request analyses at
        several different settings on the same image. After initial request, the
        following streaming requests no long need to transmit the image pixel
        data anymore, but only the new parameter settings, which saves network
        bandwidth.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDetectionOnGrid(self, request_iterator, context):
        """Send the image dataset as a stream of (overlapping or non-overlapping) image
        patches, instead of one large chunk of binary data. There are two use
        cases for this call: (1) The image dataset is too large therefore sending
        all data in one message would exceed GRPC message size limit; (2) The
        original data were taken as a grid scan so it is convinent to read/write
        as patches.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunModelAdaptation(self, request_iterator, context):
        """Run model adaptation based on the submitted stream of DetectionRequest,
        which may or may not contain ROI annotations. The all returns an opaque
        data strcuture representing the model configuration after model
        adaptation, which in turn should be included in future inference reuest
        as a DetectionSetting field.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectDetectionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RunDetection': grpc.unary_unary_rpc_method_handler(
                    servicer.RunDetection,
                    request_deserializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.FromString,
                    response_serializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.SerializeToString,
            ),
            'RunDetectionStream': grpc.stream_stream_rpc_method_handler(
                    servicer.RunDetectionStream,
                    request_deserializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.FromString,
                    response_serializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.SerializeToString,
            ),
            'RunDetectionOnGrid': grpc.stream_unary_rpc_method_handler(
                    servicer.RunDetectionOnGrid,
                    request_deserializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.FromString,
                    response_serializer=biopb_dot_image_dot_detection__response__pb2.DetectionResponse.SerializeToString,
            ),
            'RunModelAdaptation': grpc.stream_unary_rpc_method_handler(
                    servicer.RunModelAdaptation,
                    request_deserializer=biopb_dot_image_dot_detection__request__pb2.DetectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_any__pb2.Any.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'biopb.image.ObjectDetection', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('biopb.image.ObjectDetection', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ObjectDetection(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RunDetection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/biopb.image.ObjectDetection/RunDetection',
            biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
            biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RunDetectionStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/biopb.image.ObjectDetection/RunDetectionStream',
            biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
            biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RunDetectionOnGrid(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/biopb.image.ObjectDetection/RunDetectionOnGrid',
            biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
            biopb_dot_image_dot_detection__response__pb2.DetectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RunModelAdaptation(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/biopb.image.ObjectDetection/RunModelAdaptation',
            biopb_dot_image_dot_detection__request__pb2.DetectionRequest.SerializeToString,
            google_dot_protobuf_dot_any__pb2.Any.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/roi.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/roi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import bindata_pb2 as biopb_dot_ome_dot_bindata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x62iopb/ome/roi.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/bindata.proto\"}\n\x0f\x41\x66\x66ineTransform\x12\x10\n\x03\x61\x30\x30\x18\x01 \x01(\x02R\x03\x61\x30\x30\x12\x10\n\x03\x61\x30\x31\x18\x02 \x01(\x02R\x03\x61\x30\x31\x12\x10\n\x03\x61\x30\x32\x18\x03 \x01(\x02R\x03\x61\x30\x32\x12\x10\n\x03\x61\x31\x30\x18\x04 \x01(\x02R\x03\x61\x31\x30\x12\x10\n\x03\x61\x31\x31\x18\x05 \x01(\x02R\x03\x61\x31\x31\x12\x10\n\x03\x61\x31\x32\x18\x06 \x01(\x02R\x03\x61\x31\x32\"S\n\tRectangle\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x14\n\x05width\x18\x03 \x01(\x02R\x05width\x12\x14\n\x05heigh\x18\x04 \x01(\x02R\x05heigh\"}\n\x04Mask\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x14\n\x05width\x18\x03 \x01(\x02R\x05width\x12\x14\n\x05heigh\x18\x04 \x01(\x02R\x05heigh\x12-\n\x08\x62in_data\x18\x05 \x01(\x0b\x32\x12.biopb.ome.BinDataR\x07\x62inData\"#\n\x05Point\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\"[\n\x07\x45llipse\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x19\n\x08radius_x\x18\x03 \x01(\x02R\x07radiusX\x12\x19\n\x08radius_y\x18\x04 \x01(\x02R\x07radiusY\"F\n\x04Line\x12\x0e\n\x02x1\x18\x01 \x01(\x02R\x02x1\x12\x0e\n\x02y1\x18\x02 \x01(\x02R\x02y1\x12\x0e\n\x02x2\x18\x03 \x01(\x02R\x02x2\x12\x0e\n\x02y2\x18\x04 \x01(\x02R\x02y2\"\xdf\x01\n\x08PolyLine\x12(\n\x06points\x18\x01 \x03(\x0b\x32\x10.biopb.ome.PointR\x06points\x12=\n\x0cmarker_start\x18\x02 \x01(\x0e\x32\x1a.biopb.ome.PolyLine.MarkerR\x0bmarkerStart\x12\x39\n\nmarker_end\x18\x03 \x01(\x0e\x32\x1a.biopb.ome.PolyLine.MarkerR\tmarkerEnd\"/\n\x06Marker\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05\x41RROW\x10\x01\x12\t\n\x05OTHER\x10\x02\"3\n\x07Polygon\x12(\n\x06points\x18\x01 \x03(\x0b\x32\x10.biopb.ome.PointR\x06points\"#\n\x05Label\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\"\x95\t\n\x05Shape\x12\x38\n\ttransform\x18\x02 \x01(\x0b\x32\x1a.biopb.ome.AffineTransformR\ttransform\x12\"\n\nfill_color\x18\x03 \x01(\rH\x01R\tfillColor\x88\x01\x01\x12\x36\n\tfill_rule\x18\x04 \x01(\x0e\x32\x19.biopb.ome.Shape.FillRuleR\x08\x66illRule\x12&\n\x0cstroke_color\x18\x05 \x01(\rH\x02R\x0bstrokeColor\x88\x01\x01\x12&\n\x0cstroke_width\x18\x06 \x01(\x02H\x03R\x0bstrokeWidth\x88\x01\x01\x12*\n\x11stroke_width_unit\x18\x07 \x01(\tR\x0fstrokeWidthUnit\x12(\n\x10stoke_dash_array\x18\x08 \x01(\tR\x0estokeDashArray\x12\x12\n\x04text\x18\t \x01(\tR\x04text\x12\x1f\n\x0b\x66ont_family\x18\n \x01(\tR\nfontFamily\x12 \n\tfont_size\x18\x0b \x01(\x02H\x04R\x08\x66ontSize\x88\x01\x01\x12$\n\x0e\x66ont_size_unit\x18\x0c \x01(\tR\x0c\x66ontSizeUnit\x12\x1d\n\nfont_style\x18\r \x01(\tR\tfontStyle\x12\x1b\n\x06locked\x18\x0e \x01(\x08H\x05R\x06locked\x88\x01\x01\x12\x18\n\x05the_z\x18\x0f \x01(\rH\x06R\x04theZ\x88\x01\x01\x12\x18\n\x05the_t\x18\x10 \x01(\rH\x07R\x04theT\x88\x01\x01\x12\x18\n\x05the_c\x18\x11 \x01(\rH\x08R\x04theC\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\x12 \x03(\tR\rannotationIds\x12\x34\n\trectangle\x18\x13 \x01(\x0b\x32\x14.biopb.ome.RectangleH\x00R\trectangle\x12%\n\x04mask\x18\x14 \x01(\x0b\x32\x0f.biopb.ome.MaskH\x00R\x04mask\x12(\n\x05point\x18\x15 \x01(\x0b\x32\x10.biopb.ome.PointH\x00R\x05point\x12.\n\x07\x65llipse\x18\x16 \x01(\x0b\x32\x12.biopb.ome.EllipseH\x00R\x07\x65llipse\x12%\n\x04line\x18\x17 \x01(\x0b\x32\x0f.biopb.ome.LineH\x00R\x04line\x12\x31\n\x08polyLine\x18\x18 \x01(\x0b\x32\x13.biopb.ome.PolyLineH\x00R\x08polyLine\x12.\n\x07polygon\x18\x19 \x01(\x0b\x32\x12.biopb.ome.PolygonH\x00R\x07polygon\x12(\n\x05label\x18\x1a \x01(\x0b\x32\x10.biopb.ome.LabelH\x00R\x05label\"@\n\x08\x46illRule\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x45VENODD\x10\x01\x12\x0b\n\x07NONZERO\x10\x02\x12\t\n\x05OTHER\x10\x03\x42\r\n\x0bshape_groupB\r\n\x0b_fill_colorB\x0f\n\r_stroke_colorB\x0f\n\r_stroke_widthB\x0c\n\n_font_sizeB\t\n\x07_lockedB\x08\n\x06_the_zB\x08\n\x06_the_tB\x08\n\x06_the_c\"\x8c\x01\n\x03ROI\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12(\n\x06shapes\x18\x04 \x03(\x0b\x32\x10.biopb.ome.ShapeR\x06shapes\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.roi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_AFFINETRANSFORM']._serialized_start=59
  _globals['_AFFINETRANSFORM']._serialized_end=184
  _globals['_RECTANGLE']._serialized_start=186
  _globals['_RECTANGLE']._serialized_end=269
  _globals['_MASK']._serialized_start=271
  _globals['_MASK']._serialized_end=396
  _globals['_POINT']._serialized_start=398
  _globals['_POINT']._serialized_end=433
  _globals['_ELLIPSE']._serialized_start=435
  _globals['_ELLIPSE']._serialized_end=526
  _globals['_LINE']._serialized_start=528
  _globals['_LINE']._serialized_end=598
  _globals['_POLYLINE']._serialized_start=601
  _globals['_POLYLINE']._serialized_end=824
  _globals['_POLYLINE_MARKER']._serialized_start=777
  _globals['_POLYLINE_MARKER']._serialized_end=824
  _globals['_POLYGON']._serialized_start=826
  _globals['_POLYGON']._serialized_end=877
  _globals['_LABEL']._serialized_start=879
  _globals['_LABEL']._serialized_end=914
  _globals['_SHAPE']._serialized_start=917
  _globals['_SHAPE']._serialized_end=2090
  _globals['_SHAPE_FILLRULE']._serialized_start=1907
  _globals['_SHAPE_FILLRULE']._serialized_end=1971
  _globals['_ROI']._serialized_start=2093
  _globals['_ROI']._serialized_end=2233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/plate.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/plate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/ome/plate.proto\x12\tbiopb.ome\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd6\x02\n\x10PlateAcquisition\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x39\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x33\n\x13maximum_field_count\x18\x06 \x01(\rH\x00R\x11maximumFieldCount\x88\x01\x01\x12&\n\x0fwell_sample_ids\x18\x07 \x03(\tR\rwellSampleIds\x12%\n\x0e\x61nnotation_ids\x18\x08 \x03(\tR\rannotationIdsB\x16\n\x14_maximum_field_count\"\xb2\x02\n\nWellSample\x12\x19\n\x08image_id\x18\x02 \x01(\tR\x07imageId\x12\"\n\nposition_x\x18\x03 \x01(\x02H\x00R\tpositionX\x88\x01\x01\x12\"\n\nposition_y\x18\x04 \x01(\x02H\x01R\tpositionY\x88\x01\x01\x12(\n\x10positioin_x_unit\x18\x05 \x01(\tR\x0epositioinXUnit\x12(\n\x10positioin_y_unit\x18\x06 \x01(\tR\x0epositioinYUnit\x12\x39\n\ntime_point\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimePoint\x12\x14\n\x05index\x18\x08 \x01(\rR\x05indexB\r\n\x0b_position_xB\r\n\x0b_position_y\"\xfc\x02\n\x04Well\x12\x43\n\x0cwell_samples\x18\x02 \x03(\x0b\x32 .biopb.ome.Well.WellSamplesEntryR\x0bwellSamples\x12\x16\n\x06\x63olumn\x18\x03 \x01(\rR\x06\x63olumn\x12\x10\n\x03row\x18\x04 \x01(\rR\x03row\x12/\n\x13\x65xternal_identifier\x18\x05 \x01(\tR\x12\x65xternalIdentifier\x12\x12\n\x04type\x18\x06 \x01(\tR\x04type\x12\x19\n\x05\x63olor\x18\x07 \x01(\rH\x00R\x05\x63olor\x88\x01\x01\x12\x1d\n\nreagent_id\x18\x08 \x01(\tR\treagentId\x12%\n\x0e\x61nnotation_ids\x18\t \x03(\tR\rannotationIds\x1aU\n\x10WellSamplesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.WellSampleR\x05value:\x02\x38\x01\x42\x08\n\x06_color\"\xdd\x07\n\x05Plate\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12/\n\x13\x65xternal_identifier\x18\x05 \x01(\tR\x12\x65xternalIdentifier\x12[\n\x18\x43olumn_naming_convention\x18\x06 \x01(\x0e\x32!.biopb.ome.Plate.NamingConventionR\x16\x43olumnNamingConvention\x12U\n\x15row_naming_convention\x18\x07 \x01(\x0e\x32!.biopb.ome.Plate.NamingConventionR\x13rowNamingConvention\x12\"\n\rwell_origin_x\x18\x08 \x01(\x02R\x0bwellOriginX\x12\"\n\rwell_origin_y\x18\t \x01(\x02R\x0bwellOriginY\x12+\n\x12well_origin_x_unit\x18\n \x01(\tR\x0fwellOriginXUnit\x12+\n\x12well_origin_y_unit\x18\x0b \x01(\tR\x0fwellOriginYUnit\x12\x12\n\x04rows\x18\x0c \x01(\rR\x04rows\x12\x18\n\x07\x63olumns\x18\r \x01(\rR\x07\x63olumns\x12\x31\n\x05wells\x18\x0e \x03(\x0b\x32\x1b.biopb.ome.Plate.WellsEntryR\x05wells\x12V\n\x12plate_acquisitions\x18\x0f \x03(\x0b\x32\'.biopb.ome.Plate.PlateAcquisitionsEntryR\x11plateAcquisitions\x12$\n\x0b\x66ield_index\x18\x11 \x01(\rH\x00R\nfieldIndex\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\x12 \x03(\tR\rannotationIds\x1aI\n\nWellsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.biopb.ome.WellR\x05value:\x02\x38\x01\x1a\x61\n\x16PlateAcquisitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.PlateAcquisitionR\x05value:\x02\x38\x01\";\n\x10NamingConvention\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06LETTER\x10\x01\x12\n\n\x06NUMBER\x10\x02\x42\x0e\n\x0c_field_indexB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.plate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_WELL_WELLSAMPLESENTRY']._loaded_options = None
  _globals['_WELL_WELLSAMPLESENTRY']._serialized_options = b'8\001'
  _globals['_PLATE_WELLSENTRY']._loaded_options = None
  _globals['_PLATE_WELLSENTRY']._serialized_options = b'8\001'
  _globals['_PLATE_PLATEACQUISITIONSENTRY']._loaded_options = None
  _globals['_PLATE_PLATEACQUISITIONSENTRY']._serialized_options = b'8\001'
  _globals['_PLATEACQUISITION']._serialized_start=70
  _globals['_PLATEACQUISITION']._serialized_end=412
  _globals['_WELLSAMPLE']._serialized_start=415
  _globals['_WELLSAMPLE']._serialized_end=721
  _globals['_WELL']._serialized_start=724
  _globals['_WELL']._serialized_end=1104
  _globals['_WELL_WELLSAMPLESENTRY']._serialized_start=1009
  _globals['_WELL_WELLSAMPLESENTRY']._serialized_end=1094
  _globals['_PLATE']._serialized_start=1107
  _globals['_PLATE']._serialized_end=2096
  _globals['_PLATE_WELLSENTRY']._serialized_start=1847
  _globals['_PLATE_WELLSENTRY']._serialized_end=1920
  _globals['_PLATE_PLATEACQUISITIONSENTRY']._serialized_start=1922
  _globals['_PLATE_PLATEACQUISITIONSENTRY']._serialized_end=2019
  _globals['_PLATE_NAMINGCONVENTION']._serialized_start=2021
  _globals['_PLATE_NAMINGCONVENTION']._serialized_end=2080
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/instrument.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/instrument.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import microscope_pb2 as biopb_dot_ome_dot_microscope__pb2
from biopb.ome import light_source_pb2 as biopb_dot_ome_dot_light__source__pb2
from biopb.ome import detector_pb2 as biopb_dot_ome_dot_detector__pb2
from biopb.ome import objective_pb2 as biopb_dot_ome_dot_objective__pb2
from biopb.ome import filter_set_pb2 as biopb_dot_ome_dot_filter__set__pb2
from biopb.ome import filter_pb2 as biopb_dot_ome_dot_filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/instrument.proto\x12\tbiopb.ome\x1a\x1a\x62iopb/ome/microscope.proto\x1a\x1c\x62iopb/ome/light_source.proto\x1a\x18\x62iopb/ome/detector.proto\x1a\x19\x62iopb/ome/objective.proto\x1a\x1a\x62iopb/ome/filter_set.proto\x1a\x16\x62iopb/ome/filter.proto\"\x85\x08\n\nInstrument\x12\x35\n\nmicroscope\x18\x01 \x01(\x0b\x32\x15.biopb.ome.MicroscopeR\nmicroscope\x12L\n\rlight_sources\x18\x02 \x03(\x0b\x32\'.biopb.ome.Instrument.LightSourcesEntryR\x0clightSources\x12\x42\n\tdetectors\x18\x03 \x03(\x0b\x32$.biopb.ome.Instrument.DetectorsEntryR\tdetectors\x12\x45\n\nobjectives\x18\x04 \x03(\x0b\x32%.biopb.ome.Instrument.ObjectivesEntryR\nobjectives\x12\x46\n\x0b\x66ilter_sets\x18\x05 \x03(\x0b\x32%.biopb.ome.Instrument.FilterSetsEntryR\nfilterSets\x12<\n\x07\x66ilters\x18\x06 \x03(\x0b\x32\".biopb.ome.Instrument.FiltersEntryR\x07\x66ilters\x12\x42\n\tdichroics\x18\x07 \x03(\x0b\x32$.biopb.ome.Instrument.DichroicsEntryR\tdichroics\x12%\n\x0e\x61nnotation_ids\x18\x08 \x03(\tR\rannotationIds\x1aW\n\x11LightSourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.biopb.ome.LightSourceR\x05value:\x02\x38\x01\x1aQ\n\x0e\x44\x65tectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.biopb.ome.DetectorR\x05value:\x02\x38\x01\x1aS\n\x0fObjectivesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.biopb.ome.ObjectiveR\x05value:\x02\x38\x01\x1aS\n\x0f\x46ilterSetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.biopb.ome.FilterSetR\x05value:\x02\x38\x01\x1aM\n\x0c\x46iltersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FilterR\x05value:\x02\x38\x01\x1aQ\n\x0e\x44ichroicsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.biopb.ome.DichroicR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.instrument_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._loaded_options = None
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_DETECTORSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._loaded_options = None
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_FILTERSETSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_FILTERSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_DICHROICSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT']._serialized_start=205
  _globals['_INSTRUMENT']._serialized_end=1234
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_start=732
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_end=819
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_start=821
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_end=902
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_start=904
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_end=987
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_start=989
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_end=1072
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_start=1074
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_end=1151
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_start=1153
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_end=1234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/detector_setting.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/detector_setting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n biopb/ome/detector_setting.proto\x12\tbiopb.ome\"\xb3\x03\n\x0f\x44\x65tectorSetting\x12\x1f\n\x0b\x64\x65tector_id\x18\x01 \x01(\tR\ndetectorId\x12\x1b\n\x06offset\x18\x02 \x01(\x02H\x00R\x06offset\x88\x01\x01\x12\x17\n\x04gain\x18\x03 \x01(\x02H\x01R\x04gain\x88\x01\x01\x12\x1d\n\x07voltage\x18\x04 \x01(\x02H\x02R\x07voltage\x88\x01\x01\x12!\n\x0cvoltage_unit\x18\x05 \x01(\tR\x0bvoltageUnit\x12\x17\n\x04zoom\x18\x06 \x01(\x02H\x03R\x04zoom\x88\x01\x01\x12&\n\x0creadout_rate\x18\x07 \x01(\x02H\x04R\x0breadoutRate\x88\x01\x01\x12*\n\x11readout_rate_unit\x18\x08 \x01(\tR\x0freadoutRateUnit\x12\x1d\n\x07\x62inning\x18\t \x01(\rH\x05R\x07\x62inning\x88\x01\x01\x12%\n\x0bintegration\x18\n \x01(\rH\x06R\x0bintegration\x88\x01\x01\x42\t\n\x07_offsetB\x07\n\x05_gainB\n\n\x08_voltageB\x07\n\x05_zoomB\x0f\n\r_readout_rateB\n\n\x08_binningB\x0e\n\x0c_integrationB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.detector_setting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_DETECTORSETTING']._serialized_start=48
  _globals['_DETECTORSETTING']._serialized_end=483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/objective.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/objective.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x62iopb/ome/objective.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xb2\x06\n\tObjective\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12?\n\ncorrection\x18\x03 \x01(\x0e\x32\x1f.biopb.ome.Objective.CorrectionR\ncorrection\x12\x1c\n\temmersion\x18\x04 \x01(\tR\temmersion\x12\x1c\n\x07lens_na\x18\x05 \x01(\x02H\x00R\x06lensNa\x88\x01\x01\x12\x38\n\x15nominal_magnification\x18\x06 \x01(\x02H\x01R\x14nominalMagnification\x88\x01\x01\x12>\n\x18\x63\x61librated_magnification\x18\x07 \x01(\x02H\x02R\x17\x63\x61libratedMagnification\x88\x01\x01\x12.\n\x10working_distance\x18\x08 \x01(\x02H\x03R\x0fworkingDistance\x88\x01\x01\x12\x32\n\x15working_distance_unit\x18\t \x01(\tR\x13workingDistanceUnit\x12\x17\n\x04iris\x18\n \x01(\x08H\x04R\x04iris\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\x0b \x03(\tR\rannotationIds\"\xde\x01\n\nCorrection\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02UV\x10\x01\x12\x0b\n\x07PLANAPO\x10\x02\x12\r\n\tPLANFLUOR\x10\x03\x12\x0e\n\nSUPERFLUOR\x10\x04\x12\x13\n\x0fVIOLETCORRECTED\x10\x05\x12\t\n\x05\x41\x43HRO\x10\x06\x12\x0c\n\x08\x41\x43HROMAT\x10\x07\x12\t\n\x05\x46LUOR\x10\x08\x12\x06\n\x02\x46L\x10\t\x12\t\n\x05\x46LUAR\x10\n\x12\x0c\n\x08\x45NOFLUAR\x10\x0b\x12\x0b\n\x07\x46LUOTAR\x10\x0c\x12\x07\n\x03\x41PO\x10\r\x12\x10\n\x0cPLANNEOFLUAR\x10\x0e\x12\t\n\x05OTHER\x10\x0f\x42\n\n\x08_lens_naB\x18\n\x16_nominal_magnificationB\x1b\n\x19_calibrated_magnificationB\x13\n\x11_working_distanceB\x07\n\x05_irisB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.objective_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_OBJECTIVE']._serialized_start=76
  _globals['_OBJECTIVE']._serialized_end=894
  _globals['_OBJECTIVE_CORRECTION']._serialized_start=575
  _globals['_OBJECTIVE_CORRECTION']._serialized_end=797
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/microbeam_manipulation.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/microbeam_manipulation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import light_source_setting_pb2 as biopb_dot_ome_dot_light__source__setting__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&biopb/ome/microbeam_manipulation.proto\x12\tbiopb.ome\x1a$biopb/ome/light_source_setting.proto\"\xff\x01\n\x15MicrobeamManipulation\x12/\n\x04type\x18\x02 \x01(\x0e\x32\x1b.biopb.ome.ManipulationTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x17\n\x07roi_ids\x18\x04 \x03(\tR\x06roiIds\x12Q\n\x15light_source_settings\x18\x05 \x03(\x0b\x32\x1d.biopb.ome.LightSourceSettingR\x13lightSourceSettings\x12\'\n\x0f\x65xperimenter_id\x18\x06 \x01(\tR\x0e\x65xperimenterId*\x89\x01\n\x10ManipulationType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x46RAP\x10\x01\x12\x08\n\x04\x46LIP\x10\x02\x12\x0f\n\x0bINVERSEFRAP\x10\x03\x12\x11\n\rPHOTOABLATION\x10\x04\x12\x0c\n\x08UNCAGING\x10\x05\x12\x13\n\x0fOPTICALTRAPPING\x10\x06\x12\t\n\x05OTHER\x10\x07\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.microbeam_manipulation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_MANIPULATIONTYPE']._serialized_start=350
  _globals['_MANIPULATIONTYPE']._serialized_end=487
  _globals['_MICROBEAMMANIPULATION']._serialized_start=92
  _globals['_MICROBEAMMANIPULATION']._serialized_end=347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/microscope.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/microscope.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/microscope.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xec\x01\n\nMicroscope\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12.\n\x04type\x18\x03 \x01(\x0e\x32\x1a.biopb.ome.Microscope.TypeR\x04type\"d\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UPRIGHT\x10\x01\x12\x0c\n\x08INVERTED\x10\x02\x12\x0e\n\nDISSECTION\x10\x03\x12\x15\n\x11\x45LECTROPHYSIOLOGY\x10\x04\x12\t\n\x05OTHER\x10\x05\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.microscope_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_MICROSCOPE']._serialized_start=77
  _globals['_MICROSCOPE']._serialized_end=313
  _globals['_MICROSCOPE_TYPE']._serialized_start=213
  _globals['_MICROSCOPE_TYPE']._serialized_end=313
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/filter.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/filter.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xd7\x03\n\x12TransmittanceRange\x12\x1a\n\x06\x63ut_in\x18\x02 \x01(\x02H\x00R\x05\x63utIn\x88\x01\x01\x12\x1e\n\x0b\x63ut_in_unit\x18\x03 \x01(\tR\tcutInUnit\x12\x1c\n\x07\x63ut_out\x18\x04 \x01(\x02H\x01R\x06\x63utOut\x88\x01\x01\x12 \n\x0c\x63ut_out_unit\x18\x05 \x01(\tR\ncutOutUnit\x12-\n\x10\x63ut_in_tolerance\x18\x06 \x01(\x02H\x02R\x0e\x63utInTolerance\x88\x01\x01\x12\x31\n\x15\x63ut_in_tolerance_unit\x18\x07 \x01(\tR\x12\x63utInToleranceUnit\x12/\n\x11\x63ut_out_tolerance\x18\x08 \x01(\x02H\x03R\x0f\x63utOutTolerance\x88\x01\x01\x12\x33\n\x16\x63ut_out_tolerance_unit\x18\t \x01(\tR\x13\x63utOutToleranceUnit\x12)\n\rtransmittance\x18\n \x01(\x02H\x04R\rtransmittance\x88\x01\x01\x42\t\n\x07_cut_inB\n\n\x08_cut_outB\x13\n\x11_cut_in_toleranceB\x14\n\x12_cut_out_toleranceB\x10\n\x0e_transmittance\"\xa6\x03\n\x06\x46ilter\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12*\n\x04type\x18\x03 \x01(\x0e\x32\x16.biopb.ome.Filter.TypeR\x04type\x12N\n\x13transmittence_range\x18\x04 \x01(\x0b\x32\x1d.biopb.ome.TransmittanceRangeR\x12transmittenceRange\x12!\n\x0c\x66ilter_wheel\x18\x05 \x01(\tR\x0b\x66ilterWheel\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\"\x8b\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ICHROIC\x10\x01\x12\x0c\n\x08LONGPASS\x10\x02\x12\r\n\tSHORTPASS\x10\x03\x12\x0c\n\x08\x42\x41NDPASS\x10\x04\x12\r\n\tMULTIPASS\x10\x05\x12\x12\n\x0eNEUTRALDENSITY\x10\x06\x12\x0b\n\x07TUNABLE\x10\x07\x12\t\n\x05OTHER\x10\x08\"{\n\x08\x44ichroic\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_TRANSMITTANCERANGE']._serialized_start=73
  _globals['_TRANSMITTANCERANGE']._serialized_end=544
  _globals['_FILTER']._serialized_start=547
  _globals['_FILTER']._serialized_end=969
  _globals['_FILTER_TYPE']._serialized_start=830
  _globals['_FILTER_TYPE']._serialized_end=969
  _globals['_DICHROIC']._serialized_start=971
  _globals['_DICHROIC']._serialized_end=1094
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/experiment.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/experiment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import microbeam_manipulation_pb2 as biopb_dot_ome_dot_microbeam__manipulation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/experiment.proto\x12\tbiopb.ome\x1a&biopb/ome/microbeam_manipulation.proto\"\xae\x05\n\nExperiment\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32$.biopb.ome.Experiment.ExperimentTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12j\n\x17microbeam_manipulations\x18\x04 \x03(\x0b\x32\x31.biopb.ome.Experiment.MicrobeamManipulationsEntryR\x16microbeamManipulations\x12\'\n\x0f\x65xperimenter_id\x18\x05 \x01(\tR\x0e\x65xperimenterId\x1ak\n\x1bMicrobeamManipulationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32 .biopb.ome.MicrobeamManipulationR\x05value:\x02\x38\x01\"\xc1\x02\n\x0e\x45xperimentType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02\x46P\x10\x01\x12\x08\n\x04\x46RET\x10\x02\x12\r\n\tTIMELAPSE\x10\x03\x12\r\n\tFOURDPLUS\x10\x04\x12\n\n\x06SCREEN\x10\x05\x12\x17\n\x13IMMUNOCYTOCHEMISTRY\x10\x06\x12\x16\n\x12IMMUNOFLUORESCENCE\x10\x07\x12\x08\n\x04\x46ISH\x10\x08\x12\x15\n\x11\x45LECTROPHYSIOLOGY\x10\t\x12\x0e\n\nIONIMAGING\x10\n\x12\x12\n\x0e\x43OLOCALIZATION\x10\x0b\x12\x14\n\x10PGIDOCUMENTATION\x10\x0c\x12\x18\n\x14\x46LUORESCENCELIFETIME\x10\r\x12\x13\n\x0fSPECTRALIMAGING\x10\x0e\x12\x12\n\x0ePHOTOBLEACHING\x10\x0f\x12\x08\n\x04SPIM\x10\x10\x12\t\n\x05OTHER\x10\x11\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.experiment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._loaded_options = None
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPERIMENT']._serialized_start=82
  _globals['_EXPERIMENT']._serialized_end=768
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_start=337
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_end=444
  _globals['_EXPERIMENT_EXPERIMENTTYPE']._serialized_start=447
  _globals['_EXPERIMENT_EXPERIMENTTYPE']._serialized_end=768
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/light_source.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/light_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x62iopb/ome/light_source.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x83\x05\n\x05Laser\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x15.biopb.ome.Laser.TypeR\x04type\x12!\n\x0claser_medium\x18\x03 \x01(\tR\x0blaserMedium\x12#\n\nWavelength\x18\x04 \x01(\x02H\x00R\nWavelength\x88\x01\x01\x12\'\n\x0fwavelength_unit\x18\x05 \x01(\tR\x0ewavelengthUnit\x12<\n\x17\x66\x65quency_multiplication\x18\x06 \x01(\x05H\x01R\x16\x66\x65quencyMultiplication\x88\x01\x01\x12\x1d\n\x07tunable\x18\x07 \x01(\x08H\x02R\x07tunable\x88\x01\x01\x12\x14\n\x05pulse\x18\x08 \x01(\tR\x05pulse\x12$\n\x0bpockel_cell\x18\t \x01(\x08H\x03R\npockelCell\x88\x01\x01\x12,\n\x0frepetition_rate\x18\n \x01(\rH\x04R\x0erepetitionRate\x88\x01\x01\x12\x30\n\x14repetition_rate_unit\x18\x0b \x01(\tR\x12repetitionRateUnit\"\x89\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XCIMER\x10\x01\x12\x07\n\x03GAS\x10\x02\x12\x0f\n\x0bMETAL_VAPOR\x10\x03\x12\x0f\n\x0bSOLID_STATE\x10\x04\x12\x07\n\x03\x44YE\x10\x05\x12\x11\n\rSEMICONDUCTOR\x10\x06\x12\x11\n\rFREE_ELECTRON\x10\x07\x12\t\n\x05OTHER\x10\x08\x42\r\n\x0b_WavelengthB\x1a\n\x18_fequency_multiplicationB\n\n\x08_tunableB\x0e\n\x0c_pockel_cellB\x12\n\x10_repetition_rate\"m\n\x03\x41rc\x12\'\n\x04type\x18\x02 \x01(\x0e\x32\x13.biopb.ome.Arc.TypeR\x04type\"=\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02HG\x10\x01\x12\x06\n\x02XE\x10\x02\x12\t\n\x05HG_XE\x10\x03\x12\t\n\x05OTHER\x10\x04\"{\n\x08\x46ilament\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x18.biopb.ome.Filament.TypeR\x04type\"A\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x10\n\x0cINCANDESCENT\x10\x01\x12\x0b\n\x07HALOGEN\x10\x02\x12\t\n\x05OTHER\x10\x03\"\x14\n\x12LightEmittingDiode\"\xac\x01\n\x17GenericExcitationSource\x12R\n\nattributes\x18\x02 \x03(\x0b\x32\x32.biopb.ome.GenericExcitationSource.AttributesEntryR\nattributes\x1a=\n\x0f\x41ttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8a\x04\n\x0bLightSource\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12\x19\n\x05power\x18\x03 \x01(\x02H\x01R\x05power\x88\x01\x01\x12\x1f\n\x0bpower_units\x18\x04 \x01(\tR\npowerUnits\x12%\n\x0e\x61nnotation_ids\x18\x05 \x01(\tR\rannotationIds\x12(\n\x05laser\x18\x06 \x01(\x0b\x32\x10.biopb.ome.LaserH\x00R\x05laser\x12\"\n\x03\x61rc\x18\x07 \x01(\x0b\x32\x0e.biopb.ome.ArcH\x00R\x03\x61rc\x12\x31\n\x08\x66ilament\x18\x08 \x01(\x0b\x32\x13.biopb.ome.FilamentH\x00R\x08\x66ilament\x12Q\n\x14light_emitting_diode\x18\t \x01(\x0b\x32\x1d.biopb.ome.LightEmittingDiodeH\x00R\x12lightEmittingDiode\x12`\n\x19generic_excitation_source\x18\n \x01(\x0b\x32\".biopb.ome.GenericExcitationSourceH\x00R\x17genericExcitationSourceB\x0e\n\x0clight_sourceB\x08\n\x06_powerB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.light_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_LASER']._serialized_start=79
  _globals['_LASER']._serialized_end=722
  _globals['_LASER_TYPE']._serialized_start=494
  _globals['_LASER_TYPE']._serialized_end=631
  _globals['_ARC']._serialized_start=724
  _globals['_ARC']._serialized_end=833
  _globals['_ARC_TYPE']._serialized_start=772
  _globals['_ARC_TYPE']._serialized_end=833
  _globals['_FILAMENT']._serialized_start=835
  _globals['_FILAMENT']._serialized_end=958
  _globals['_FILAMENT_TYPE']._serialized_start=893
  _globals['_FILAMENT_TYPE']._serialized_end=958
  _globals['_LIGHTEMITTINGDIODE']._serialized_start=960
  _globals['_LIGHTEMITTINGDIODE']._serialized_end=980
  _globals['_GENERICEXCITATIONSOURCE']._serialized_start=983
  _globals['_GENERICEXCITATIONSOURCE']._serialized_end=1155
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_start=1094
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_end=1155
  _globals['_LIGHTSOURCE']._serialized_start=1158
  _globals['_LIGHTSOURCE']._serialized_end=1680
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/detector.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/detector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62iopb/ome/detector.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x95\x05\n\x08\x44\x65tector\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x18.biopb.ome.Detector.TypeR\x04type\x12\x17\n\x04gain\x18\x04 \x01(\x02H\x00R\x04gain\x88\x01\x01\x12\x1d\n\x07voltage\x18\x05 \x01(\x02H\x01R\x07voltage\x88\x01\x01\x12!\n\x0cvoltage_unit\x18\x06 \x01(\tR\x0bvoltageUnit\x12\x1b\n\x06offset\x18\x07 \x01(\x02H\x02R\x06offset\x88\x01\x01\x12\x17\n\x04zoom\x18\x08 \x01(\x02H\x03R\x04zoom\x88\x01\x01\x12\x32\n\x12\x61mplification_gain\x18\t \x01(\x02H\x04R\x11\x61mplificationGain\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\n \x03(\tR\rannotationIds\"\xe4\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03\x43\x43\x44\x10\x01\x12\x13\n\x0fINTENSIFIED_CCD\x10\x02\x12\x10\n\x0c\x41NALOG_VIDEO\x10\x03\x12\x07\n\x03PMT\x10\x04\x12\x0e\n\nPHOTODIODE\x10\x05\x12\x10\n\x0cSPECTROSCOPY\x10\x06\x12\x14\n\x10LIFETIME_IMAGING\x10\x07\x12\x1c\n\x18\x43ORRELATION_SPECTROSCOPY\x10\x08\x12\x08\n\x04\x46TIR\x10\t\x12\t\n\x05\x45MCCD\x10\n\x12\x07\n\x03\x41PD\x10\x0b\x12\x08\n\x04\x43MOD\x10\x0c\x12\t\n\x05\x45\x42\x43\x43\x44\x10\r\x12\t\n\x05OTHER\x10\x0e\x42\x07\n\x05_gainB\n\n\x08_voltageB\t\n\x07_offsetB\x07\n\x05_zoomB\x15\n\x13_amplification_gainB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.detector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_DETECTOR']._serialized_start=75
  _globals['_DETECTOR']._serialized_end=736
  _globals['_DETECTOR_TYPE']._serialized_start=444
  _globals['_DETECTOR_TYPE']._serialized_end=672
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/screen.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/screen.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import reagent_pb2 as biopb_dot_ome_dot_reagent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/screen.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/reagent.proto\"\xa6\x03\n\x06Screen\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12;\n\x08reagents\x18\x03 \x03(\x0b\x32\x1f.biopb.ome.Screen.ReagentsEntryR\x08reagents\x12\x1b\n\tplate_ids\x18\x04 \x03(\tR\x08plateIds\x12/\n\x13protocol_identifier\x18\x05 \x01(\tR\x12protocolIdentifier\x12\x31\n\x14protocol_description\x18\x06 \x01(\tR\x13protocolDescription\x12/\n\x13reagent_description\x18\x07 \x01(\tR\x12reagentDescription\x12\x34\n\x16reagent_set_identifier\x18\x08 \x01(\tR\x14reagentSetIdentifier\x12\x12\n\x04type\x18\t \x01(\tR\x04type\x1aO\n\rReagentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.ReagentR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.screen_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_SCREEN_REAGENTSENTRY']._loaded_options = None
  _globals['_SCREEN_REAGENTSENTRY']._serialized_options = b'8\001'
  _globals['_SCREEN']._serialized_start=63
  _globals['_SCREEN']._serialized_end=485
  _globals['_SCREEN_REAGENTSENTRY']._serialized_start=406
  _globals['_SCREEN_REAGENTSENTRY']._serialized_end=485
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/rpc_object_detection.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/rpc_object_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from biopb.image import detection_request_pb2 as biopb_dot_image_dot_detection__request__pb2
from biopb.image import detection_response_pb2 as biopb_dot_image_dot_detection__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&biopb/image/rpc_object_detection.proto\x12\x0b\x62iopb.image\x1a\x19google/protobuf/any.proto\x1a#biopb/image/detection_request.proto\x1a$biopb/image/detection_response.proto2\xdd\x02\n\x0fObjectDetection\x12M\n\x0cRunDetection\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse\x12W\n\x12RunDetectionStream\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse(\x01\x30\x01\x12U\n\x12RunDetectionOnGrid\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse(\x01\x12K\n\x12RunModelAdaptation\x12\x1d.biopb.image.DetectionRequest\x1a\x14.google.protobuf.Any(\x01\x42\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.rpc_object_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_OBJECTDETECTION']._serialized_start=158
  _globals['_OBJECTDETECTION']._serialized_end=507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/rpc_process_image.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/rpc_process_image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from biopb.image import image_data_pb2 as biopb_dot_image_dot_image__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#biopb/image/rpc_process_image.proto\x12\x0b\x62iopb.image\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1c\x62iopb/image/image_data.proto\"\x9b\x01\n\x0eProcessRequest\x12\x35\n\nimage_data\x18\x01 \x01(\x0b\x32\x16.biopb.image.ImageDataR\timageData\x12\x17\n\x07op_name\x18\x02 \x01(\tR\x06opName\x12\x39\n\nfield_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"h\n\x0fProcessResponse\x12\x35\n\nimage_data\x18\x01 \x01(\x0b\x32\x16.biopb.image.ImageDataR\timageData\x12\x1e\n\nannotation\x18\x02 \x01(\tR\nannotation\"\x1f\n\x07OpNames\x12\x14\n\x05names\x18\x01 \x03(\tR\x05names2\xd8\x01\n\x0cProcessImage\x12@\n\x03Run\x12\x1b.biopb.image.ProcessRequest\x1a\x1c.biopb.image.ProcessResponse\x12J\n\tRunStream\x12\x1b.biopb.image.ProcessRequest\x1a\x1c.biopb.image.ProcessResponse(\x01\x30\x01\x12:\n\nGetOpNames\x12\x16.google.protobuf.Empty\x1a\x14.biopb.image.OpNamesB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.rpc_process_image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_PROCESSREQUEST']._serialized_start=146
  _globals['_PROCESSREQUEST']._serialized_end=301
  _globals['_PROCESSRESPONSE']._serialized_start=303
  _globals['_PROCESSRESPONSE']._serialized_end=407
  _globals['_OPNAMES']._serialized_start=409
  _globals['_OPNAMES']._serialized_end=440
  _globals['_PROCESSIMAGE']._serialized_start=443
  _globals['_PROCESSIMAGE']._serialized_end=659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/ome.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/ome.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import rights_pb2 as biopb_dot_ome_dot_rights__pb2
from biopb.ome import metadata_pb2 as biopb_dot_ome_dot_metadata__pb2
from biopb.ome import metadata_ref_pb2 as biopb_dot_ome_dot_metadata__ref__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x62iopb/ome/ome.proto\x12\tbiopb.ome\x1a\x16\x62iopb/ome/rights.proto\x1a\x18\x62iopb/ome/metadata.proto\x1a\x1c\x62iopb/ome/metadata_ref.proto\"\xca\x01\n\x03OME\x12)\n\x06rights\x18\x01 \x01(\x0b\x32\x11.biopb.ome.RightsR\x06rights\x12/\n\x08metadata\x18\x02 \x01(\x0b\x32\x13.biopb.ome.MetadataR\x08metadata\x12\x39\n\x0cmetadata_ref\x18\x03 \x01(\x0b\x32\x16.biopb.ome.MetadataRefR\x0bmetadataRef\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x18\n\x07\x63reator\x18\x05 \x01(\tR\x07\x63reatorB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.ome_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_OME']._serialized_start=115
  _globals['_OME']._serialized_end=317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/pixel.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/pixel.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import bindata_pb2 as biopb_dot_ome_dot_bindata__pb2
from biopb.ome import light_source_setting_pb2 as biopb_dot_ome_dot_light__source__setting__pb2
from biopb.ome import detector_setting_pb2 as biopb_dot_ome_dot_detector__setting__pb2
from biopb.ome import lightpath_pb2 as biopb_dot_ome_dot_lightpath__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/ome/pixel.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/bindata.proto\x1a$biopb/ome/light_source_setting.proto\x1a biopb/ome/detector_setting.proto\x1a\x19\x62iopb/ome/lightpath.proto\"\xa0\x04\n\x05Plane\x12\x1b\n\thash_sha1\x18\x01 \x01(\x0cR\x08hashSha1\x12\x18\n\x05the_z\x18\x02 \x01(\rH\x00R\x04theZ\x88\x01\x01\x12\x18\n\x05the_t\x18\x03 \x01(\rH\x01R\x04theT\x88\x01\x01\x12\x18\n\x05the_c\x18\x04 \x01(\rH\x02R\x04theC\x88\x01\x01\x12\x1c\n\x07\x64\x65lta_t\x18\x05 \x01(\x02H\x03R\x06\x64\x65ltaT\x88\x01\x01\x12\x1e\n\x0b\x64\x65lt_t_unit\x18\x06 \x01(\tR\tdeltTUnit\x12(\n\rexposure_time\x18\x07 \x01(\x02H\x04R\x0c\x65xposureTime\x88\x01\x01\x12,\n\x12\x65xposure_time_unit\x18\x08 \x01(\tR\x10\x65xposureTimeUnit\x12 \n\tpostion_x\x18\t \x01(\x02H\x05R\x08postionX\x88\x01\x01\x12 \n\tpostion_y\x18\n \x01(\x02H\x06R\x08postionY\x88\x01\x01\x12 \n\tpostion_z\x18\x0b \x01(\x02H\x07R\x08postionZ\x88\x01\x01\x12#\n\rposition_unit\x18\x0c \x01(\tR\x0cpositionUnit\x12%\n\x0e\x61nnotation_ids\x18\x0f \x03(\tR\rannotationIdsB\x08\n\x06_the_zB\x08\n\x06_the_tB\x08\n\x06_the_cB\n\n\x08_delta_tB\x10\n\x0e_exposure_timeB\x0c\n\n_postion_xB\x0c\n\n_postion_yB\x0c\n\n_postion_z\"\xb3\x08\n\x07\x43hannel\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12O\n\x14light_source_setting\x18\x03 \x01(\x0b\x32\x1d.biopb.ome.LightSourceSettingR\x12lightSourceSetting\x12\x45\n\x10\x64\x65tector_setting\x18\x04 \x01(\x0b\x32\x1a.biopb.ome.DetectorSettingR\x0f\x64\x65tectorSetting\x12!\n\x0c\x46ilterSet_id\x18\x05 \x01(\tR\x0b\x46ilterSetId\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\x12\x33\n\nlight_path\x18\x07 \x01(\x0b\x32\x14.biopb.ome.LightPathR\tlightPath\x12/\n\x11samples_per_pixel\x18\x08 \x01(\rH\x00R\x0fsamplesPerPixel\x88\x01\x01\x12+\n\x11illumination_type\x18\t \x01(\tR\x10illuminationType\x12&\n\x0cpinhole_size\x18\n \x01(\x02H\x01R\x0bpinholeSize\x88\x01\x01\x12*\n\x11pinhole_size_unit\x18\x0b \x01(\tR\x0fpinholeSizeUnit\x12+\n\x11\x61\x63quisition_model\x18\x0c \x01(\tR\x10\x61\x63quisitionModel\x12\'\n\x0f\x63ontrast_method\x18\r \x01(\tR\x0e\x63ontrastMethod\x12\x38\n\x15\x65xcitation_wavelength\x18\x0e \x01(\x02H\x02R\x14\x65xcitationWavelength\x88\x01\x01\x12:\n\x19\x65xitation_wavelength_unit\x18\x0f \x01(\tR\x17\x65xitationWavelengthUnit\x12\x34\n\x13\x65mission_wavelength\x18\x10 \x01(\x02H\x03R\x12\x65missionWavelength\x88\x01\x01\x12\x38\n\x18\x65mission_wavelength_unit\x18\x11 \x01(\tR\x16\x65missionWavelengthUnit\x12\x14\n\x05\x66luor\x18\x12 \x01(\tR\x05\x66luor\x12 \n\tnd_filter\x18\x13 \x01(\x02H\x04R\x08ndFilter\x88\x01\x01\x12\x33\n\x13pockle_cell_setting\x18\x14 \x01(\x05H\x05R\x11pockleCellSetting\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x15 \x01(\rH\x06R\x05\x63olor\x88\x01\x01\x42\x14\n\x12_samples_per_pixelB\x0f\n\r_pinhole_sizeB\x18\n\x16_excitation_wavelengthB\x16\n\x14_emission_wavelengthB\x0c\n\n_nd_filterB\x16\n\x14_pockle_cell_settingB\x08\n\x06_color\"\xbe\x08\n\x06Pixels\x12.\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x12.biopb.ome.ChannelR\x08\x63hannels\x12(\n\x06planes\x18\x02 \x03(\x0b\x32\x10.biopb.ome.PlaneR\x06planes\x12,\n\x07\x62indata\x18\x03 \x03(\x0b\x32\x12.biopb.ome.BinDataR\x07\x62indata\x12\'\n\x0f\x64imension_order\x18\x04 \x01(\tR\x0e\x64imensionOrder\x12:\n\npixel_type\x18\x05 \x01(\x0e\x32\x1b.biopb.ome.Pixels.PixelTypeR\tpixelType\x12.\n\x10significant_bits\x18\x06 \x01(\rH\x00R\x0fsignificantBits\x88\x01\x01\x12%\n\x0binterleaved\x18\x07 \x01(\x08H\x01R\x0binterleaved\x88\x01\x01\x12\"\n\nbig_endian\x18\x08 \x01(\x08H\x02R\tbigEndian\x88\x01\x01\x12\x15\n\x06size_x\x18\t \x01(\rR\x05sizeX\x12\x15\n\x06size_y\x18\n \x01(\rR\x05sizeY\x12\x15\n\x06size_z\x18\x0b \x01(\rR\x05sizeZ\x12\x15\n\x06size_c\x18\x0c \x01(\rR\x05sizeC\x12\x15\n\x06size_t\x18\r \x01(\rR\x05sizeT\x12+\n\x0fphysical_size_x\x18\x0e \x01(\x02H\x03R\rphysicalSizeX\x88\x01\x01\x12+\n\x0fphysical_size_y\x18\x0f \x01(\x02H\x04R\rphysicalSizeY\x88\x01\x01\x12+\n\x0fphysical_size_z\x18\x10 \x01(\x02H\x05R\rphysicalSizeZ\x88\x01\x01\x12,\n\x12physical_size_unit\x18\x11 \x01(\tR\x10physicalSizeUnit\x12*\n\x0etime_increment\x18\x12 \x01(\x02H\x06R\rtimeIncrement\x88\x01\x01\x12.\n\x13time_increment_unit\x18\x15 \x01(\tR\x11timeIncrementUnit\"\xc4\x01\n\tPixelType\x12\x12\n\x0ePT_UNSPECIFIED\x10\x00\x12\x0b\n\x07PT_INT8\x10\x01\x12\x0c\n\x08PT_INT16\x10\x02\x12\x0c\n\x08PT_INT32\x10\x03\x12\x0c\n\x08PT_UINT8\x10\x04\x12\r\n\tPT_UINT16\x10\x05\x12\r\n\tPT_UINT32\x10\x06\x12\x0c\n\x08PT_FLOAT\x10\x07\x12\r\n\tPT_DOUBLE\x10\x08\x12\x0e\n\nPT_COMPLEX\x10\t\x12\x15\n\x11PT_DOUBLE_COMPLEX\x10\n\x12\n\n\x06PT_BIT\x10\x0b\x42\x13\n\x11_significant_bitsB\x0e\n\x0c_interleavedB\r\n\x0b_big_endianB\x12\n\x10_physical_size_xB\x12\n\x10_physical_size_yB\x12\n\x10_physical_size_zB\x11\n\x0f_time_incrementB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.pixel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_PLANE']._serialized_start=161
  _globals['_PLANE']._serialized_end=705
  _globals['_CHANNEL']._serialized_start=708
  _globals['_CHANNEL']._serialized_end=1783
  _globals['_PIXELS']._serialized_start=1786
  _globals['_PIXELS']._serialized_end=2872
  _globals['_PIXELS_PIXELTYPE']._serialized_start=2545
  _globals['_PIXELS_PIXELTYPE']._serialized_end=2741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/rights.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/rights.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/rights.proto\x12\tbiopb.ome\"N\n\x06Rights\x12#\n\rrights_holder\x18\x01 \x01(\tR\x0crightsHolder\x12\x1f\n\x0brights_held\x18\x02 \x01(\tR\nrightsHeldB\x15\n\tbiopb.omeB\x06RightsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.rights_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeB\006RightsP\001'
  _globals['_RIGHTS']._serialized_start=37
  _globals['_RIGHTS']._serialized_end=115
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/image.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from biopb.ome import objective_setting_pb2 as biopb_dot_ome_dot_objective__setting__pb2
from biopb.ome import pixel_pb2 as biopb_dot_ome_dot_pixel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/ome/image.proto\x12\tbiopb.ome\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!biopb/ome/objective_setting.proto\x1a\x15\x62iopb/ome/pixel.proto\"\xbf\x02\n\x12ImagingEnvironment\x12%\n\x0btemperature\x18\x01 \x01(\x02H\x00R\x0btemperature\x88\x01\x01\x12)\n\x10temperature_unit\x18\x02 \x01(\tR\x0ftemperatureUnit\x12&\n\x0c\x61ir_pressure\x18\x03 \x01(\x02H\x01R\x0b\x61irPressure\x88\x01\x01\x12*\n\x11\x61ir_pressure_unit\x18\x04 \x01(\tR\x0f\x61irPressureUnit\x12\x1f\n\x08humidity\x18\x05 \x01(\x02H\x02R\x08humidity\x88\x01\x01\x12$\n\x0b\x63o2_percent\x18\x06 \x01(\x02H\x03R\nco2Percent\x88\x01\x01\x42\x0e\n\x0c_temperatureB\x0f\n\r_air_pressureB\x0b\n\t_humidityB\x0e\n\x0c_co2_percent\"\xb0\x01\n\nStageLabel\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x11\n\x01x\x18\x03 \x01(\x02H\x00R\x01x\x88\x01\x01\x12\x15\n\x06x_unit\x18\x04 \x01(\tR\x05xUnit\x12\x11\n\x01y\x18\x05 \x01(\x02H\x01R\x01y\x88\x01\x01\x12\x15\n\x06y_unit\x18\x06 \x01(\tR\x05yUnit\x12\x11\n\x01z\x18\x07 \x01(\x02H\x02R\x01z\x88\x01\x01\x12\x15\n\x06z_unit\x18\x08 \x01(\tR\x05zUnitB\x04\n\x02_xB\x04\n\x02_yB\x04\n\x02_z\"\xa2\x05\n\x05Image\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x45\n\x10\x61\x63quisition_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x61\x63quisitionDate\x12\'\n\x0f\x65xperimenter_id\x18\x05 \x01(\tR\x0e\x65xperimenterId\x12#\n\rexperiment_id\x18\x06 \x01(\tR\x0c\x65xperimentId\x12.\n\x13\x65xperiment_group_id\x18\x07 \x01(\tR\x11\x65xperimentGroupId\x12#\n\rinstrument_id\x18\x08 \x01(\tR\x0cinstrumentId\x12<\n\x1amicrobeam_manipulation_ids\x18\t \x03(\tR\x18microbeamManipulationIds\x12\x17\n\x07roi_ids\x18\n \x03(\tR\x06roiIds\x12%\n\x0e\x61nnotation_ids\x18\x0b \x03(\tR\rannotationIds\x12H\n\x11objective_setting\x18\x0c \x01(\x0b\x32\x1b.biopb.ome.ObjectiveSettingR\x10objectiveSetting\x12N\n\x13imaging_environment\x18\r \x01(\x0b\x32\x1d.biopb.ome.ImagingEnvironmentR\x12imagingEnvironment\x12\x36\n\x0bstage_label\x18\x0e \x01(\x0b\x32\x15.biopb.ome.StageLabelR\nstageLabel\x12)\n\x06pixels\x18\x0f \x01(\x0b\x32\x11.biopb.ome.PixelsR\x06pixelsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_IMAGINGENVIRONMENT']._serialized_start=128
  _globals['_IMAGINGENVIRONMENT']._serialized_end=447
  _globals['_STAGELABEL']._serialized_start=450
  _globals['_STAGELABEL']._serialized_end=626
  _globals['_IMAGE']._serialized_start=629
  _globals['_IMAGE']._serialized_end=1303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/detection_settings.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/detection_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$biopb/image/detection_settings.proto\x12\x0b\x62iopb.image\x1a\x19google/protobuf/any.proto\"\xc9\x03\n\x11\x44\x65tectionSettings\x12\'\n\rmin_cell_area\x18\x01 \x01(\x02H\x01R\x0bminCellArea\x88\x01\x01\x12 \n\tmin_score\x18\x02 \x01(\x02H\x02R\x08minScore\x88\x01\x01\x12:\n\x16segmentation_threshold\x18\x03 \x01(\x02H\x03R\x15segmentationThreshold\x88\x01\x01\x12\x1c\n\x07nms_iou\x18\x04 \x01(\x02H\x04R\x06nmsIou\x88\x01\x01\x12.\n\x12\x63\x65ll_diameter_hint\x18\x06 \x01(\x02H\x00R\x10\x63\x65llDiameterHint\x12#\n\x0cscaling_hint\x18\x07 \x01(\x02H\x00R\x0bscalingHint\x12\x1d\n\nmodel_name\x18\x08 \x01(\tR\tmodelName\x12\x45\n\x13model_configuration\x18\t \x01(\x0b\x32\x14.google.protobuf.AnyR\x12modelConfigurationB\r\n\x0bresize_infoB\x10\n\x0e_min_cell_areaB\x0c\n\n_min_scoreB\x19\n\x17_segmentation_thresholdB\n\n\x08_nms_iouB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.detection_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_DETECTIONSETTINGS']._serialized_start=81
  _globals['_DETECTIONSETTINGS']._serialized_end=538
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from biopb.image import rpc_process_image_pb2 as biopb_dot_image_dot_rpc__process__image__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ProcessImageStub(object):
    """A generic image process protocol that returns a new image. Examples include
    denoising, super-resolution, and semantic segmentation.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Run = channel.unary_unary(
                '/biopb.image.ProcessImage/Run',
                request_serializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.SerializeToString,
                response_deserializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.FromString,
                _registered_method=True)
        self.RunStream = channel.stream_stream(
                '/biopb.image.ProcessImage/RunStream',
                request_serializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.SerializeToString,
                response_deserializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.FromString,
                _registered_method=True)
        self.GetOpNames = channel.unary_unary(
                '/biopb.image.ProcessImage/GetOpNames',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=biopb_dot_image_dot_rpc__process__image__pb2.OpNames.FromString,
                _registered_method=True)


class ProcessImageServicer(object):
    """A generic image process protocol that returns a new image. Examples include
    denoising, super-resolution, and semantic segmentation.

    """

    def Run(self, request, context):
        """Process the input image
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunStream(self, request_iterator, context):
        """Streaming version 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOpNames(self, request, context):
        """Query operation names. Server with a single op may not implement this
        call.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProcessImageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Run': grpc.unary_unary_rpc_method_handler(
                    servicer.Run,
                    request_deserializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.FromString,
                    response_serializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.SerializeToString,
            ),
            'RunStream': grpc.stream_stream_rpc_method_handler(
                    servicer.RunStream,
                    request_deserializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.FromString,
                    response_serializer=biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.SerializeToString,
            ),
            'GetOpNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOpNames,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=biopb_dot_image_dot_rpc__process__image__pb2.OpNames.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'biopb.image.ProcessImage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('biopb.image.ProcessImage', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProcessImage(object):
    """A generic image process protocol that returns a new image. Examples include
    denoising, super-resolution, and semantic segmentation.

    """

    @staticmethod
    def Run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/biopb.image.ProcessImage/Run',
            biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.SerializeToString,
            biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RunStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/biopb.image.ProcessImage/RunStream',
            biopb_dot_image_dot_rpc__process__image__pb2.ProcessRequest.SerializeToString,
            biopb_dot_image_dot_rpc__process__image__pb2.ProcessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOpNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/biopb.image.ProcessImage/GetOpNames',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            biopb_dot_image_dot_rpc__process__image__pb2.OpNames.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/folder.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/folder.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/folder.proto\x12\tbiopb.ome\"\xb1\x02\n\x06\x46older\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x42\n\x0bsub_folders\x18\x04 \x03(\x0b\x32!.biopb.ome.Folder.SubFoldersEntryR\nsubFolders\x12\x1b\n\timage_ids\x18\x05 \x03(\tR\x08imageIds\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\x12\x17\n\x07roi_ids\x18\x07 \x03(\tR\x06roiIds\x1aP\n\x0fSubFoldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FolderR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.folder_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_FOLDER_SUBFOLDERSENTRY']._loaded_options = None
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_FOLDER']._serialized_start=38
  _globals['_FOLDER']._serialized_end=343
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_start=263
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_end=343
# @@protoc_insertion_point(module_scope)
